//  STIM 2  for test
//
// renoir header_end

`resetall
`timescale 1ns/1ps
`include "C:/Xilinx/verilog/src/glbl.v"
// clock 40 MHz
//`define per 25	    
//`define high 12.5
//`define low 12.5
`define per 25000	    
`define high 12500
`define low 12500

//these are designator values in decimal
`define load_skew       1
`define firmware_id_reg 3   // read firmware ID reg read only = UserCode
`define lm82_cntl       5   // LM82 control register
`define trig_int_st		6
`define dataout      	7
`define addrout      	8
`define link_reg		9
`define vfe_type_reg	10
`define soft_rst        12
`define fifo_rst        13
`define monitor         20
`define lm82_status    	27   // LM82 I2C data in
`define datain          29
`define trig_data_reg	30


module toplevel_twelve_stim2( 
   clk, clkB, rstB, serial_in, readout_synch_in);

parameter DESIGNATOR = 5; // Number of bits in Command Designator
parameter LENGTH_FIELD = 16; // Number of bits in Command Length

// Internal Declarations

output        clk;
output        clkB;
output        rstB;
output        serial_in;
output		  readout_synch_in;

reg        clk;
reg        rstB;
reg        serial_in;
reg		   readout_synch_in;

integer 	a, b;

always
begin
	#`high	clk = 0;
	#`low	clk = 1;
end

assign clkB = !clk;

/////////////////////////////////////////////////
//    THIS IS THE BEGINNING OF THE STIMULUS    //
/////////////////////////////////////////////////
initial
begin
	set_defaults;
    stimulus3;
end
/////////////////////////////////////////////////

task set_defaults;
begin
	clk = 1;
	rstB = 0;
	serial_in = 0; 
    readout_synch_in = 0 ;
end
endtask


task stimulus3;
// This one side-steps the autocal procedure (saves time).
// Thereafter anything you like.
begin
	#2 ;
	#`per	;
	#(220*`per)	rstB = 1; // Long reset to allow time for DCM to settle
	#(2 * `per);

	#(50 * `per);   // wait for DCM to settle after reset


// read firmware id
	#(20 * `per);

	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 1); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `firmware_id_reg);	// rd firmware_id_reg	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 35);	// Length of argumaent
	serial_out(35, 0);				
	serial_out(10, 0);				// Set serial_in low

// send soft reset
	#(20 * `per);

	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 1); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `soft_rst);	// rd firmware_id_reg	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 35);	// Length of argumaent
	serial_out(35, 0);				
	serial_out(10, 0);				// Set serial_in low

// read link register
	#(20 * `per);

	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 1); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `link_reg);	// rd firmware_id_reg	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 35);	// Length of argumaent
	serial_out(35, 0);				
	serial_out(10, 0);				// Set serial_in low


// write to LM82 Control
	#(20 * `per);
	serial_out(1, 1); 			// set 1st bit to 1 = header
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `lm82_cntl);	// wr lm82_cntl	 

	serial_out(1, 1); 		     // set header bit to 1
	serial_out(LENGTH_FIELD, 32);	// Length of argumaent
	serial_out(15, 0);						
	serial_out(1, 0);			// write 0x00755			
	serial_out(1, 0);						
	serial_out(1, 0);						
	serial_out(1, 0);						
	serial_out(1, 0);						
	serial_out(1, 0);						
	serial_out(1, 1);						
	serial_out(1, 1);						
	serial_out(1, 1);						
	serial_out(1, 0);						
	serial_out(1, 1);						
	serial_out(1, 0);						
	serial_out(1, 1);						
	serial_out(1, 0);						
	serial_out(1, 1);						
	serial_out(1, 0);						
	serial_out(1, 1);						
	serial_out(10, 0);			// Set serial_in low

// Read LM82 Status
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 1); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `lm82_status);	// rd lm82 status	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 35);	// Length of argumaent
	serial_out(35, 0);				
	serial_out(10, 0);				// Set serial_in low

// Reset Trig counter register
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `trig_data_reg);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 1);	// Length of argument
	serial_out(1, 1);				
			
	serial_out(10, 0);				// Set serial_in low

// Load TCALIB WIDTH DATA
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `addrout);	// wr addr	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 10);	// Length of argument
	serial_out(2, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);								
	serial_out(10, 0);				// Set serial_in low

	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `dataout);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 32);	// Length of argument
	serial_out(16, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 0);
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);								
	serial_out(10, 0);				// Set serial_in low

// Read data
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 1); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `datain);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 35);	// Length of argument
	serial_out(35, 0);				
			
	serial_out(10, 0);				// Set serial_in low

// TCALIB CAL ENABLE
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `addrout);	// wr addr	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 10);	// Length of argument
	serial_out(2, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);								
	serial_out(10, 0);				// Set serial_in low

	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `dataout);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 32);	// Length of argument
	serial_out(16, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 1);								
	serial_out(10, 0);				// Set serial_in low

// Read data
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 1); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `datain);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 35);	// Length of argument
	serial_out(35, 0);				
			
	serial_out(10, 0);				// Set serial_in low

// TRIG Delay Count
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `addrout);	// wr addr	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 10);	// Length of argument
	serial_out(2, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 0);								
	serial_out(10, 0);				// Set serial_in low

	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `dataout);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 32);	// Length of argument
	serial_out(1, 0);				
	serial_out(16, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 0);								
	serial_out(10, 0);				// Set serial_in low

// Read data
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 1); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `datain);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 35);	// Length of argument
	serial_out(35, 0);				
			
	serial_out(10, 0);				// Set serial_in low

// Hold Duration  
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `addrout);	// wr addr	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 10);	// Length of argument
	serial_out(2, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 1);								
	serial_out(10, 0);				// Set serial_in low

	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `dataout);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 32);	// Length of argument
	serial_out(1, 0);				
	serial_out(16, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 0);
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);								
	serial_out(10, 0);				// Set serial_in low

// Read data
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 1); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `datain);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 35);	// Length of argument
	serial_out(35, 0);				
			
	serial_out(10, 0);				// Set serial_in low

// Hold Inversion (BIT 0)  
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `addrout);	// wr addr	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 10);	// Length of argument
	serial_out(2, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 1);				
	serial_out(1, 0);								
	serial_out(10, 0);				// Set serial_in low

	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `dataout);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 32);	// Length of argument
	serial_out(1, 0);				
	serial_out(16, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);								
	serial_out(10, 0);				// Set serial_in low

// Read data
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 1); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `datain);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 35);	// Length of argument
	serial_out(35, 0);				
			
	serial_out(10, 0);				// Set serial_in low



// VFE TRIG
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `addrout);	// wr addr	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 10);	// Length of argument
	serial_out(2, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 0);								
	serial_out(10, 0);				// Set serial_in low

	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `dataout);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 32);	// Length of argument
	serial_out(1, 0);				
	serial_out(16, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 0);
	serial_out(1, 1);				
	serial_out(1, 1);				
	serial_out(1, 1);				
	serial_out(1, 1);								
	serial_out(10, 0);				// Set serial_in low

// Read data
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 1); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `datain);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 35);	// Length of argument
	serial_out(35, 0);				
			
	serial_out(10, 0);				// Set serial_in low

	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `addrout);	// wr addr	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 10);	// Length of argument
	serial_out(2, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 1);								
	serial_out(10, 0);				// Set serial_in low

	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `dataout);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 32);	// Length of argument
	serial_out(16, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 1);				
	serial_out(1, 1);
	serial_out(1, 1);				
	serial_out(1, 1);				
	serial_out(1, 1);				
	serial_out(1, 1);								
	serial_out(10, 0);				// Set serial_in low

// Read data
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 1); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `datain);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 35);	// Length of argument
	serial_out(35, 0);				
			
	serial_out(10, 0);				// Set serial_in low


// VFE RESET
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `addrout);	// wr addr	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 10);	// Length of argument
	serial_out(2, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);
	serial_out(1, 1);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 0);								
	serial_out(10, 0);				// Set serial_in low

	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `dataout);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 32);	// Length of argument
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(16, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 0);
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);								
	serial_out(10, 0);				// Set serial_in low


// Read data
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 1); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `datain);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 35);	// Length of argument
	serial_out(35, 0);				
			
	serial_out(10, 0);				// Set serial_in low

	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `addrout);	// wr addr	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 10);	// Length of argument
	serial_out(2, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);
	serial_out(1, 1);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 1);								
	serial_out(10, 0);				// Set serial_in low

	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `dataout);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 32);	// Length of argument
	serial_out(16, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 1);				
	serial_out(1, 0);
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);								
	serial_out(10, 0);				// Set serial_in low

// Read data
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 1); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `datain);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 35);	// Length of argument
	serial_out(35, 0);				
			
	serial_out(10, 0);				// Set serial_in low

// VFE SRIN
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `addrout);	// wr addr	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 10);	// Length of argument
	serial_out(2, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);								
	serial_out(10, 0);				// Set serial_in low

	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `dataout);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 32);	// Length of argument
	serial_out(1, 0);				
	serial_out(16, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);								
	serial_out(10, 0);				// Set serial_in low

// Read data
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 1); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `datain);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 35);	// Length of argument
	serial_out(35, 0);				
			
	serial_out(10, 0);				// Set serial_in low

	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `addrout);	// wr addr	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 10);	// Length of argument
	serial_out(2, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);								
	serial_out(10, 0);				// Set serial_in low

	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `dataout);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 32);	// Length of argument
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(16, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 0);
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);								
	serial_out(10, 0);				// Set serial_in low

// Read data
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 1); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `datain);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 35);	// Length of argument
	serial_out(35, 0);				
			
	serial_out(10, 0);				// Set serial_in low


// VFE MUX CLK start
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `addrout);	// wr addr	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 10);	// Length of argument
	serial_out(2, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 0);								
	serial_out(10, 0);				// Set serial_in low

	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `dataout);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 32);	// Length of argument
	serial_out(16, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 0);
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);								
	serial_out(10, 0);				// Set serial_in low

// Read data
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 1); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `datain);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 35);	// Length of argument
	serial_out(35, 0);				
			
	serial_out(10, 0);				// Set serial_in low

 // mux mark
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `addrout);	// wr addr	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 10);	// Length of argument
	serial_out(2, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 1);								
	serial_out(10, 0);				// Set serial_in low

	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `dataout);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 32);	// Length of argument
	serial_out(16, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 1);
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);								
	serial_out(10, 0);				// Set serial_in low

// Read data
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 1); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `datain);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 35);	// Length of argument
	serial_out(35, 0);				
			
	serial_out(10, 0);				// Set serial_in low

 // mux space
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `addrout);	// wr addr	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 10);	// Length of argument
	serial_out(2, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 1);				
	serial_out(1, 0);								
	serial_out(10, 0);				// Set serial_in low

	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `dataout);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 32);	// Length of argument
	serial_out(16, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);								
	serial_out(10, 0);				// Set serial_in low

// Read data
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 1); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `datain);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 35);	// Length of argument
	serial_out(35, 0);				
			
	serial_out(10, 0);				// Set serial_in low

 // mux count
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `addrout);	// wr addr	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 10);	// Length of argument
	serial_out(2, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 1);				
	serial_out(1, 1);								
	serial_out(10, 0);				// Set serial_in low

	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `dataout);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 32);	// Length of argument
	serial_out(16, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);								
	serial_out(10, 0);				// Set serial_in low


// Read data
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 1); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `datain);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 35);	// Length of argument
	serial_out(35, 0);				
			
	serial_out(10, 0);				// Set serial_in low


// VFE ENABLE
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `addrout);	// wr addr	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 10);	// Length of argument
	serial_out(2, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);								
	serial_out(10, 0);				// Set serial_in low

	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `dataout);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 32);	// Length of argument
	serial_out(16, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 1);
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 1);								
	serial_out(10, 0);				// Set serial_in low

// Read data
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 1); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `datain);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 35);	// Length of argument
	serial_out(35, 0);				
			
	serial_out(10, 0);				// Set serial_in low

// ADC EN
//Start
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `addrout);	// wr addr	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 10);	// Length of argument
	serial_out(2, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);
	serial_out(1, 1);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 0);								
	serial_out(10, 0);				// Set serial_in low

	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `dataout);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 32);	// Length of argument
	serial_out(16, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 1);				
	serial_out(1, 0);
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);								
	serial_out(10, 0);				// Set serial_in low

// Read data
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 1); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `datain);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 35);	// Length of argument
	serial_out(35, 0);				
			
	serial_out(10, 0);				// Set serial_in low

// End
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `addrout);	// wr addr	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 10);	// Length of argument
	serial_out(2, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);
	serial_out(1, 1);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 1);								
	serial_out(10, 0);				// Set serial_in low


	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `dataout);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 32);	// Length of argument
	serial_out(1, 0);				
	serial_out(16, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);								
	serial_out(10, 0);				// Set serial_in low

// Read data
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 1); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `datain);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 35);	// Length of argument
	serial_out(35, 0);				
			
	serial_out(10, 0);				// Set serial_in low

// A0, M0, etc
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `addrout);	// wr addr	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 10);	// Length of argument
	serial_out(2, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);
	serial_out(1, 1);				
	serial_out(1, 1);				
	serial_out(1, 1);				
	serial_out(1, 0);								
	serial_out(10, 0);				// Set serial_in low


	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `dataout);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 32);	// Length of argument
	serial_out(1, 0);				
	serial_out(16, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);								
	serial_out(10, 0);				// Set serial_in low

// Read data
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 1); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `datain);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 35);	// Length of argument
	serial_out(35, 0);				
			
	serial_out(10, 0);				// Set serial_in low


// DAC EN1
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `addrout);	// wr addr	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 10);	// Length of argument
	serial_out(2, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);								
	serial_out(10, 0);				// Set serial_in low

	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `dataout);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 32);	// Length of argument
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(16, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 0);
	serial_out(1, 1);				
	serial_out(1, 1);				
	serial_out(1, 1);				
	serial_out(1, 1);								
	serial_out(10, 0);				// Set serial_in low

// Read data
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 1); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `datain);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 35);	// Length of argument
	serial_out(35, 0);				
			
	serial_out(10, 0);				// Set serial_in low

// Frame Sync delay
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `addrout);	// wr addr	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 10);	// Length of argument
	serial_out(2, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);								
	serial_out(10, 0);				// Set serial_in low


	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `dataout);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 32);	// Length of argument
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(16, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 1);								
	serial_out(10, 0);				// Set serial_in low

// Read data
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 1); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `datain);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 35);	// Length of argument
	serial_out(35, 0);				
			
	serial_out(10, 0);				// Set serial_in low

// Readout Sync delay
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `addrout);	// wr addr	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 10);	// Length of argument
	serial_out(2, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 1);								
	serial_out(10, 0);				// Set serial_in low


	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `dataout);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 32);	// Length of argument
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(16, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 1);								
	serial_out(10, 0);				// Set serial_in low

// Read data
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 1); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `datain);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 35);	// Length of argument
	serial_out(35, 0);				
			
	serial_out(10, 0);				// Set serial_in low

// DAC EN1
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `addrout);	// wr addr	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 10);	// Length of argument
	serial_out(2, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);								
	serial_out(10, 0);				// Set serial_in low

	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `dataout);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 32);	// Length of argument
	serial_out(16, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 0);
	serial_out(1, 1);				
	serial_out(1, 1);				
	serial_out(1, 1);				
	serial_out(1, 1);								
	serial_out(10, 0);				// Set serial_in low

// Read data
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 1); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `datain);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 35);	// Length of argument
	serial_out(35, 0);				
			
	serial_out(10, 0);				// Set serial_in low



// DAC EN2
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `addrout);	// wr addr	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 10);	// Length of argument
	serial_out(2, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);								
	serial_out(10, 0);				// Set serial_in low


	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `dataout);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 32);	// Length of argument
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(16, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 0);
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 1);								
	serial_out(10, 0);				// Set serial_in low


// Read data
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 1); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `datain);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 35);	// Length of argument
	serial_out(35, 0);				
			
	serial_out(10, 0);				// Set serial_in low


// fake event write  #0
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `addrout);	// wr addr	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 10);	// Length of argument
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);								
	serial_out(10, 0);				// Set serial_in low

	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `dataout);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 32);	// Length of argument
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(16, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 1);								
	serial_out(10, 0);				// Set serial_in low

// Read data
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 1); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `datain);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 35);	// Length of argument
	serial_out(35, 0);				
			
	serial_out(10, 0);				// Set serial_in low

// fake event write  #1
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `addrout);	// wr addr	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 10);	// Length of argument
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);								
	serial_out(10, 0);				// Set serial_in low

	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `dataout);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 32);	// Length of argument
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(16, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);								
	serial_out(10, 0);				// Set serial_in low

// Read data
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 1); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `datain);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 35);	// Length of argument
	serial_out(35, 0);				
			
	serial_out(10, 0);				// Set serial_in low

// fake event write  #2
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `addrout);	// wr addr	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 10);	// Length of argument
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);								
	serial_out(10, 0);				// Set serial_in low

	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `dataout);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 32);	// Length of argument
	serial_out(1, 1);				
	serial_out(1, 1);				
	serial_out(1, 1);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(16, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 1);								
	serial_out(10, 0);				// Set serial_in low

// Read data
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 1); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `datain);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 35);	// Length of argument
	serial_out(35, 0);				
			
	serial_out(10, 0);				// Set serial_in low

// fake event write  #3
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `addrout);	// wr addr	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 10);	// Length of argument
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 1);								
	serial_out(10, 0);				// Set serial_in low

	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `dataout);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 32);	// Length of argument
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(16, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 1);								
	serial_out(10, 0);				// Set serial_in low

// Read data
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 1); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `datain);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 35);	// Length of argument
	serial_out(35, 0);				
			
	serial_out(10, 0);				// Set serial_in low

// fake event write  #4
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `addrout);	// wr addr	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 10);	// Length of argument
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 0);								
	serial_out(10, 0);				// Set serial_in low

	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `dataout);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 32);	// Length of argument
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(16, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 1);				
	serial_out(1, 1);								
	serial_out(10, 0);				// Set serial_in low


// Read data
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 1); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `datain);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 35);	// Length of argument
	serial_out(35, 0);				
			
	serial_out(10, 0);				// Set serial_in low

// fake event write  #5
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `addrout);	// wr addr	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 10);	// Length of argument
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 1);				
	serial_out(1, 1);								
	serial_out(10, 0);				// Set serial_in low

	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `dataout);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 32);	// Length of argument
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(16, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 1);								
	serial_out(10, 0);				// Set serial_in low


// Read data
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 1); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `datain);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 35);	// Length of argument
	serial_out(35, 0);				
			
	serial_out(10, 0);				// Set serial_in low

// fake event write  #6
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `addrout);	// wr addr	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 10);	// Length of argument
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 1);				
	serial_out(1, 0);								
	serial_out(10, 0);				// Set serial_in low

	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `dataout);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 32);	// Length of argument
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(16, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 1);								
	serial_out(10, 0);				// Set serial_in low


// Read data
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 1); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `datain);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 35);	// Length of argument
	serial_out(35, 0);				
			
	serial_out(10, 0);				// Set serial_in low

// fake event write  #7
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `addrout);	// wr addr	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 10);	// Length of argument
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 1);				
	serial_out(1, 1);								
	serial_out(10, 0);				// Set serial_in low

	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `dataout);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 32);	// Length of argument
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(16, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 1);
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 1);								
	serial_out(10, 0);				// Set serial_in low


// Read data
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 1); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `datain);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 35);	// Length of argument
	serial_out(35, 0);				
			
	serial_out(10, 0);				// Set serial_in low


// Fake Event register
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `addrout);	// wr addr	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 10);	// Length of argument
	serial_out(1, 0);				
	serial_out(1, 1);				
	serial_out(1, 1);				
	serial_out(1, 1);				
	serial_out(1, 1);				
	serial_out(1, 1);
	serial_out(1, 1);				
	serial_out(1, 1);				
	serial_out(1, 1);				
	serial_out(1, 1);								
	serial_out(10, 0);				// Set serial_in low


	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `dataout);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 32);	// Length of argument
	serial_out(16, 0);				
	serial_out(1, 1);				
//	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);
	serial_out(1, 1);				
	serial_out(1, 0);				
	serial_out(1, 0);				
	serial_out(1, 0);								
	serial_out(10, 0);				// Set serial_in low

// Read data
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 1); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `datain);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 35);	// Length of argument
	serial_out(35, 0);				
			
	serial_out(10, 0);				// Set serial_in low


//internal triggger start

	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `trig_int_st);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 1);	// Length of argument
	serial_out(1, 0);				
			
	serial_out(100, 0);				// Set serial_in low

// Send Handshake signals
	
	#(10000 * `per)	readout_synch_in = 1;
	#`per			readout_synch_in = 0;

//	#(20000 * `per)	readout_synch_in = 1;
//	#`per			readout_synch_in = 0;
    #(800 * `per)

//internal triggger start

	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `trig_int_st);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 1);	// Length of argument
	serial_out(1, 0);				
			
	serial_out(100, 0);				// Set serial_in low

// read trig counter reg
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 1); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `trig_data_reg);	// wr data	 
  
	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 35);	// Length of argument
	serial_out(35, 0);				
			
	serial_out(10, 0);				// Set serial_in low

// send fifo reset
	#(20 * `per);

	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 1); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `fifo_rst);	// rd firmware_id_reg	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 35);	// Length of argumaent
	serial_out(35, 0);				
	serial_out(10, 0);				// Set serial_in low

// send  readout_synch_in
	#(20000 * `per)	readout_synch_in = 1;
	#`per			readout_synch_in = 0;
    #(800 * `per)

// Reset Trig counter register
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 0); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `trig_data_reg);	// wr data	 

	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 1);	// Length of argument
	serial_out(1, 1);				
			
	serial_out(10, 0);				// Set serial_in low

// read trig counter reg
	#(20 * `per);
	serial_out(1, 1); 			// set header bit to 1
	serial_out(1, 1); 			// set rd/wr ie: 1 is read and 0 is write
	serial_out(DESIGNATOR, `trig_data_reg);	// wr data	 
  
	serial_out(1, 1); 		   		// set header bit to 1
	serial_out(LENGTH_FIELD, 35);	// Length of argument
	serial_out(35, 0);				
			
	serial_out(10, 0);				// Set serial_in low


	#(80000 * `per)	$stop;

end
endtask

task stimulus4;
// This one tests the FPGA in scope mode
begin
	#2 ;
	#`per	;
	#(10*`per)	rstB = 1;
	#(100*`per) ; // Long reset to allow time for DCM to settle
//	#(8*`per)	set_registers; // Sets threshold and skew values the easy way
//	#(8*`per)	set_pedestals; // Fills up the Pedestal RAM

    # (20*`per)

//	#(600 * `per);
//	#`per			frame_synch_in = 1;
//	#`per			frame_synch_in = 0;

//	#(1200 * `per);
//	#`per			frame_synch_in = 1;
//	#`per			frame_synch_in = 0;
	
//	#(1200 * `per);
//	#`per			frame_synch_in = 1;
//	#`per			frame_synch_in = 0;
	
//	#(1200 * `per);
//	#`per			frame_synch_in = 1;
//	#`per			frame_synch_in = 0;
	
	#(1900 * `per)	readout_synch_in = 1;
	#`per			readout_synch_in = 0;

//	#(1900 * `per)	readout_synch_in = 1;
//	#`per			readout_synch_in = 0;

	#(4000 * `per)	$stop;
end
endtask



task serial_out;
input [15:0] length;
input [65535:0] value;
integer a;
begin
	for (a = length; a > 0; a = a - 1)
	begin
		serial_in = value[a-1];
		#`per;
	end
end
endtask

endmodule
